.. _SASS: http://sass-lang.com/
.. _Compass: http://compass-style.org/
.. _Watchdog: https://github.com/gorakhargosh/watchdog
.. _click: http://click.pocoo.org/5/
.. _libsass-python: https://github.com/dahlia/libsass-python

========
Boussole
========

This is a commandline interface to build `SASS`_ projects using `libsass-python`_.

Alike the Compass command line, there is a 'build' and a 'watch' actions to build all SASS files.

.. Note::
    Old SASS syntax (the *indented syntax*) is not supported and not planned.

Links
*****

* Read the documentation on `Read the docs <http://boussole.readthedocs.org/>`_;
* Download its `PyPi package <http://pypi.python.org/pypi/boussole>`_;
* Clone it on its `Github repository <https://github.com/sveetch/boussole>`_;

Requires
********

* `Watchdog`_ == 0.8.3;
* `click`_ == 5.1;
* `libsass-python`_ == 0.11.0;
